@@ -14,7 +14,15 @@ class Info:
             header name in snappi: {
                 "scapy_pkt": (construct scapy packet header)
                 "scapy_name": (scapy header name)
-                (snappi field): {
+                (snappi field 1): {
+                    "field_str": (scapy field name)
+                    "length": (length of field in bits)
+                    "bit_fixup": (bits to shift right. More info below)
+                },
+
+                ...
+
+                (snappi field X): {
                     "field_str": (scapy field name)
                     "length": (length of field in bits)
                     "bit_fixup": (bits to shift right. More info below)
@@ -105,6 +113,51 @@ class Info:
                 "cfi": {"field_str": "id", "length": 1, "bit_fixup": 3},
                 "id": {"field_str": "vlan", "length": 12, "bit_fixup": 4},
                 "tpid": {"field_str": "type", "length": 16, "bit_fixup": 0}
+            },
+            "ipv6": {
+                "scapy_pkt": IPv6(),
+                "scapy_name": "IPv6",
+                "version": {"field_str": "version", "length": 4, "bit_fixup": 0},
+                "traffic_class": {"field_str": "tc", "length": 8, "bit_fixup": 4},
+                "flow_label": {"field_str": "fl", "length": 20, "bit_fixup": 4},
+                "payload_length": {"field_str": "plen", "length": 16, "bit_fixup": 0},
+                "next_header": {"field_str": "nh", "length": 8, "bit_fixup": 0},
+                "hop_limit": {"field_str": "hlim", "length": 8, "bit_fixup": 0},
+                "src": {"field_str": "src", "length": 128, "bit_fixup": 0},
+                "dst": {"field_str": "dst", "length": 128, "bit_fixup": 0},
+            },
+            "gre": {
+                "scapy_pkt": GRE(),
+                "scapy_name": "GRE",
+                "checksum_present": {"field_str": "chksum_present", "length": 1, "bit_fixup": 0},
+                "reserved0": {"field_str": "routing_present", "length": 12, "bit_fixup": 1},
+                "version": {"field_str": "version", "length": 3, "bit_fixup": 5},
+                "protocol": {"field_str": "proto", "length": 16, "bit_fixup": 0},
+                "reserved1": {"field_str": "offset", "length": 16, "bit_fixup": 0}
+            },
+            "vxlan": {
+                "scapy_pkt": VXLAN(),
+                "scapy_name": "VXLAN",
+                "flags": {"field_str": "flags", "length": 8, "bit_fixup": 0},
+                "reserved0": {"field_str": "reserved0", "length": 24, "bit_fixup": 0},
+                "vni": {"field_str": "vni", "length": 24, "bit_fixup": 0},
+                "reserved1": {"field_str": "reserved2", "length": 8, "bit_fixup": 0}
+            },
+            "icmp": {
+                "scapy_pkt": ICMP(),
+                "scapy_name": "ICMP",
+                "type": {"field_str": "type", "length": 8, "bit_fixup": 0},
+                "code": {"field_str": "code", "length": 8, "bit_fixup": 0},
+                "identifier": {"field_str": "id", "length": 16, "bit_fixup": 0},
+                "sequence_number": {"field_str": "seq", "length": 16, "bit_fixup": 0}
+            },
+            "icmpv6": {
+                "scapy_pkt": ICMPv6EchoRequest(),
+                "scapy_name": "ICMPv6EchoRequest",
+                "type": {"field_str": "type", "length": 8, "bit_fixup": 0},
+                "code": {"field_str": "code", "length": 8, "bit_fixup": 0},
+                "identifier": {"field_str": "id", "length": 16, "bit_fixup": 0},
+                "sequence_number": {"field_str": "seq", "length": 16, "bit_fixup": 0}
             }
         }
 
@@ -118,4 +171,35 @@ class Info:
             "frames_rx_rate": "rx_pps",
             "bytes_tx_rate": "tx_bps",
             "bytes_rx_rate": "rx_bps"
+        }
+
+    def get_capture_filter_info():
+        return {
+            "ethernet": {
+                "name": "ether",
+                "src": {},
+                "dst": {},
+                "ether_type": {"offset":"[12:2]", "mask":0xffff}
+            },
+            "vlan": {
+                "name": "vlan",
+                "id": {}
+            },
+            "ipv4": {
+                "name": "ip",
+                "version": {"offset":"[0]", "mask":0xf0},
+                "header_length": {"offset":"[0]", "mask":0x0f},
+                "priority": {"offset":"[1]", "mask":0xff},
+                "total_length": {"offset":"[2:2]", "mask":0xffff},
+                "identification": {"offset":"[4:2]", "mask":0xffff},
+                "reserved": {"offset":"[6]", "mask":0x80},
+                "dont_fragment": {"offset":"[6]", "mask":0x40},
+                "more_fragments": {"offset":"[6]", "mask":0x20},
+                "fragment_offset": {"offset":"[6:2]", "mask":0x1fff},
+                "time_to_live": {"offset":"[8]", "mask":0xff},
+                "protocol": {"offset":"[9]", "mask":0xff},
+                "header_checksum": {"offset":"[10:2]", "mask":0xffff},
+                "src": {"offset":"[12:4]", "mask":0xffffffff},
+                "dst": {"offset":"[16:4]", "mask":0xffffffff},
+            }
         }
\ No newline at end of file
