@@ -97,11 +97,27 @@ class SetConfig:
 
             # Now configure the header fields
             for field in header[header_name]:
+
+                # Edge case for all icmp echo header fields
+                if (header_name == 'icmp' or header_name == 'icmpv6') and field == 'echo':
+                    for icmp_field in header[header_name][field]:
+                        field_info = header_info[header_name][icmp_field]
+                        vm_cmds += ValueOptions.get_value_cmds(
+                            layer_type=scapy_header, 
+                            layer_cnt=layer_cnt[scapy_header], 
+                            header_field=header[header_name][field][icmp_field], 
+                            length=field_info['length'], 
+                            field_str=field_info['field_str'],
+                            bit_fixup=field_info['bit_fixup']
+                        )
+                    continue
+
                 header_field = header[header_name][field]
                 # Edge case for ipv4's priority field
                 if header_name == 'ipv4' and field == 'priority':
                     header_field = header['ipv4'][field]['raw']
 
+                # General case
                 field_info = header_info[header_name][field]
                 vm_cmds += ValueOptions.get_value_cmds(
                     layer_type=scapy_header, 
@@ -126,6 +142,9 @@ class SetConfig:
                     Strings must conform to supported Scapy protocols
         """
         Validation.validate_size(f_size)
+        fcs = 0
+        if layers[0] == 'Ethernet':
+            fcs = 4
         vm_cmds = []
         if f_size['choice'] == 'increment':
             needs_trim = True
@@ -133,16 +152,16 @@ class SetConfig:
             max_pkt_size = end = f_size['increment']['end']
             step = f_size['increment']['step']
             vm_cmds.append(STLVmFlowVar(name = 'pkt_len', size = 2, op = 'inc', step = step,
-                                            min_value = start,
-                                            max_value = end))
+                                            min_value = start-fcs,
+                                            max_value = end-fcs))
 
         elif f_size['choice'] == 'random':
             needs_trim = True
             start = f_size['random']['min']
             max_pkt_size = end = f_size['random']['max']
             vm_cmds.append(STLVmFlowVar(name = 'pkt_len', size = 2, op = 'random',
-                                            min_value = start,
-                                            max_value = end))
+                                            min_value = start-fcs,
+                                            max_value = end-fcs))
 
         elif f_size['choice'] == 'fixed':
             needs_trim = False
@@ -162,6 +181,7 @@ class SetConfig:
                     layers_with_len[layer] += 1
 
         # Fill the rest of the packet with x's
+        max_pkt_size -= fcs
         pad = max(0, max_pkt_size - len(pkt_base)) * '\0'
 
         return vm_cmds, pad
