@@ -87,6 +87,10 @@ class Api(snappi.Api):
         self._loadPorts()
         self._capture.set_port_ids(self._port_ids)
 
+        if 'captures' in cfg_obj:
+            Validation.validate_capture_settings(cfg_obj['captures'], self._port_ids)
+            self._capture.set_capture_settings(self._config.captures)
+
         try:
             self._c.reset(ports = list(range(len(self._port_ids))))
             # for each Snappi flow, construct the equivalent T-Rex stream
