@@ -50,6 +50,16 @@ class Util:
                 result += int(e, 16)
             return result
 
+        if layer_type == 'IPv6':
+            elements = value.split(':')
+            result = 0
+            for e in elements:
+                result = result << 16
+                if len(e) == 0:
+                    continue
+                result += int(e, 16)
+            return result
+
         if layer_type == 'ARP':
             if len(value.split('.')) == 4:
                 return Util.convert_to_long(value, 'IP')
@@ -60,4 +70,8 @@ class Util:
         
         return value
 
-    
\ No newline at end of file
+    
+    def long_to_MAC(value):
+        return ':'.join(['{}{}'.format(a,b)
+            for a, b in zip(*[iter('{:012x}'.format(value))] * 2)
+        ])
\ No newline at end of file
