@@ -77,21 +77,33 @@ class Validation(object):
 
             if header_name not in header_info:
                 raise SnappiTrexException('Invalid packet \'header\' choice')
-            else:
-                for field in header[header_name]:
-                    if field not in header_info[header_name]:
-                        raise SnappiTrexException('\'{0}\' is not a supported \'{1}\' field'.format(field, header_name))
-                    field_info = header_info[header_name][field]
-                    header_field = header[header_name][field]
-                    if header_name == 'ipv4' and field == 'priority':
-                        if 'raw' not in header['ipv4']['priority']:
-                            raise SnappiTrexException('ipv4 \'priority\' only supports \'raw\' option')
-                        header_field = header['ipv4'][field]['raw']
-                    Validation.validate_value_option(
-                        header_field=header_field,
-                        layer_type=scapy_header,
-                        length=field_info['length']
-                    )
+
+            for field in header[header_name]:
+
+                if (header_name == 'icmp' or header_name == 'icmpv6') and field == 'echo':
+                    for icmp_field in header[header_name][field]:
+                        field_info = header_info[header_name][icmp_field]
+                        Validation.validate_value_option(
+                            header_field=header[header_name][field][icmp_field],
+                            layer_type=scapy_header,
+                            length=field_info['length']
+                        )
+                    continue
+
+                if field not in header_info[header_name]:
+                    raise SnappiTrexException('\'{0}\' is not a supported \'{1}\' field'.format(field, header_name))
+                        
+                header_field = header[header_name][field]
+                if header_name == 'ipv4' and field == 'priority':
+                    if 'raw' not in header['ipv4']['priority']:
+                        raise SnappiTrexException('ipv4 \'priority\' only supports \'raw\' option')
+                    header_field = header['ipv4'][field]['raw']
+                field_info = header_info[header_name][field]
+                Validation.validate_value_option(
+                    header_field=header_field,
+                    layer_type=scapy_header,
+                    length=field_info['length']
+                )
 
 
     def validate_size(f_size):
@@ -140,6 +152,7 @@ class Validation(object):
     def validate_increment(field_inc, layer_type, length, dir):
         Validation.validate_address(field_inc['start'], layer_type, length)
         Validation.validate_address(field_inc['step'], layer_type, length)
+        length = min(length, 64)
         if not isinstance(field_inc['count'], int):
             raise SnappiTrexException('\'count\' must be integer')
         start = Util.convert_to_long(field_inc['start'], layer_type)
@@ -219,4 +232,36 @@ class Validation(object):
                     raise SnappiTrexException('\'{}\' is not a supported metrics column'.format(col))
 
 
+    def validate_capture_settings(settings, port_ids):
+        for s in settings:
+            for p_name in s['port_names']:
+                if p_name not in port_ids:
+                    raise SnappiTrexException('\'{}\' is not a recognized port'.format(p_name))
+
+            if s['format'] != 'pcap':
+                raise SnappiTrexException('\'{}\' is not a supported capture format'.format(s['format']))
+            if s['packet_size'] is not None:
+                raise SnappiTrexException('maximum capture packet size options are not supported')
+            if s['overwrite']:
+                raise SnappiTrexException('overwrite not supported for captures')
+
+            capture_filter_info = Info.get_capture_filter_info()
+            if 'filters' in s:
+                for f in s['filters']:
+                    print(f)
+                    for proto in f:
+                        if proto == 'choice':
+                            continue
+                        if proto not in capture_filter_info:
+                            raise SnappiTrexException('\'{}\' is not a supported capture filter protocol'.format(proto))
+                        for field in f[proto]:
+                            if field not in capture_filter_info[proto]:
+                                raise SnappiTrexException('\'{}\' is not a supported capture filter {} field'.format(field, proto))
+
+
+
+
+
+
+
 
